@@ -214,11 +214,6 @@
 #' "577055", "697062", "231660", "648380", "554953", "746496", "2602969")
 #' result <- classification(ids, db = 'ncbi')
 #' }
-#'
-#' @examples \dontrun{
-#' # Fails without db param set
-#' # classification(315576)
-#' }
 classification <- function(...){
   UseMethod("classification")
 }
@@ -228,7 +223,11 @@ classification <- function(...){
 classification.default <- function(sci_id, db = NULL, callopts = list(),
                                    return_id = TRUE, rows = NA, x = NULL, ...) {
   nstop(db)
-  pchk(x, "sci_id")
+  if (!is.null(x)) {
+    lifecycle::deprecate_warn(when = "v0.9.97", what = "classification(x)", with = "classification(sci_id)")
+    sci_id <- x
+  }
+  
   switch(
     db,
     itis = {
@@ -236,9 +235,9 @@ classification.default <- function(sci_id, db = NULL, callopts = list(),
       stats::setNames(classification(id, return_id = return_id, ...), sci_id)
     },
     ncbi = {
-      id <- process_ids(sci_id, db, get_uid, rows = rows)
+      id <- process_ids(sci_id, db, get_uid, rows = rows, ...)
       stats::setNames(classification(id, callopts = callopts,
-        return_id = return_id), sci_id)
+        return_id = return_id, ...), sci_id)
     },
     eol = {
       id <- process_ids(sci_id, db, get_eolid, rows = rows, ...)
@@ -365,31 +364,33 @@ classification.uid <- function(id, callopts = list(), return_id = TRUE,
       tries <- 1
       while (success == FALSE && tries <= max_tries) {
         res <- cli$get("entrez/eutils/efetch.fcgi", query = query)
-        res$raise_for_status()
-        tt <- res$parse("UTF-8")
-        ttp <- xml2::read_xml(tt)
-        out <- lapply(xml2::xml_find_all(ttp, '//TaxaSet/Taxon'),
-          function(tax_node) {
-          lin <- data.frame(
-            name = xml_text_all(tax_node,
-              ".//LineageEx/Taxon/ScientificName"),
-            rank = xml_text_all(tax_node, ".//LineageEx/Taxon/Rank"),
-            id = xml_text_all(tax_node, ".//LineageEx/Taxon/TaxId"),
-            stringsAsFactors = FALSE)
-          targ_tax <- data.frame(
-            name = xml_text_all(tax_node, "./ScientificName"),
-            rank = xml_text_all(tax_node, "./Rank"),
-            id = xml_text_all(tax_node, "./TaxId"),
-            stringsAsFactors = FALSE)
-          rbind(lin, targ_tax)
-        })
-        # Is not directly below root and no lineage info
-        parent_id <- xml_text_all(ttp, "//TaxaSet/Taxon/ParentTaxId") %||% ""
-        out[vapply(out, NROW, numeric(1)) == 0 & parent_id != "1"] <- NA
-        # Add NA where the taxon ID was not found
-        names(out) <- xml_text(xml2::xml_find_all(ttp,
-          '//TaxaSet/Taxon/TaxId'))
-        success <- ! grepl(tt, pattern = 'error', ignore.case = TRUE)
+		try({
+			res$raise_for_status()
+			tt <- res$parse("UTF-8")
+			ttp <- xml2::read_xml(tt)
+			out <- lapply(xml2::xml_find_all(ttp, '//TaxaSet/Taxon'),
+			function(tax_node) {
+			lin <- data.frame(
+				name = xml_text_all(tax_node,
+				".//LineageEx/Taxon/ScientificName"),
+				rank = xml_text_all(tax_node, ".//LineageEx/Taxon/Rank"),
+				id = xml_text_all(tax_node, ".//LineageEx/Taxon/TaxId"),
+				stringsAsFactors = FALSE)
+			targ_tax <- data.frame(
+				name = xml_text_all(tax_node, "./ScientificName"),
+				rank = xml_text_all(tax_node, "./Rank"),
+				id = xml_text_all(tax_node, "./TaxId"),
+				stringsAsFactors = FALSE)
+			rbind(lin, targ_tax)
+			})
+			# Is not directly below root and no lineage info
+			parent_id <- xml_text_all(ttp, "//TaxaSet/Taxon/ParentTaxId") %||% ""
+			out[vapply(out, NROW, numeric(1)) == 0 & parent_id != "1"] <- NA
+			# Add NA where the taxon ID was not found
+			names(out) <- xml_text(xml2::xml_find_all(ttp,
+			'//TaxaSet/Taxon/TaxId'))
+			success <- ! grepl(tt, pattern = 'error', ignore.case = TRUE)
+		}, silent=FALSE)
         tries <- tries + 1
         # NCBI limits requests to three per second without key or 10 per
         # second with key
