@@ -115,7 +115,10 @@ downstream.default <- function(sci_id, db=NULL, downto=NULL,
                                intermediate=FALSE, rows=NA, x=NULL, ...) {
   nstop(downto, "downto")
   nstop(db)
-  pchk(x, "sci_id")
+  if (!is.null(x)) {
+    lifecycle::deprecate_warn(when = "v0.9.97", what = "downstream(x)", with = "downstream(sci_id)")
+    sci_id <- x
+  }
   if (!is.null(x)) sci_id <- x
   switch(
     db,
