@@ -1,7 +1,10 @@
+iucn_base_url <- "https://www.iucnredlist.org/details/%s/0"
+
+
 #' Get a IUCN Redlist taxon
 #'
 #' @export
-#' @param x (character) A vector of scientific names. Or, a
+#' @param sci (character) A vector of scientific names. Or, a
 #' `taxon_state` object (see [taxon-state])
 #' @param messages logical; should progress be printed?
 #' @param key (character) required. you IUCN Redlist API key. See
@@ -9,6 +12,8 @@
 #' IUCN Redlist
 #' @param check (logical) Check if ID matches any existing on the DB, only
 #' used in [as.iucn()]
+#' @param x For `get_iucn()`: Deprecated, see `sci`. For `as.iucn()`, various,
+#' see examples
 #' @param ... Ignored
 #'
 #' @return A vector of taxonomic identifiers as an S3 class.
@@ -39,84 +44,116 @@
 #' @family taxonomic-ids
 #'
 #' @examples \dontrun{
-#' get_iucn(x = "Branta canadensis")
-#' get_iucn(x = "Branta bernicla")
-#' get_iucn(x = "Panthera uncia")
+#' get_iucn("Branta canadensis")
+#' get_iucn("Branta bernicla")
+#' get_iucn("Panthera uncia")
 #'
-#' # as coercion
-#' as.iucn(22732)
-#' as.iucn("22732")
-#' (res <- as.iucn(c(22679946, 22732, 22679935)))
-#' data.frame(res)
-#' as.iucn(data.frame(res))
 #' }
-get_iucn <- function(x, messages = TRUE, key = NULL, ...) {
+get_iucn <- function(sci, messages = TRUE, key = NULL, x = NULL, ...) {
 
-  assert(x, c("character", "taxon_state"))
+  assert(sci, c("character", "taxon_state", "numeric"))
   assert(messages, "logical")
-
-  if (inherits(x, "character")) {
-    tstate <- taxon_state$new(class = "iucn", names = x)
-    items <- x
-  } else {
-    assert_state(x, "iucn")
-    tstate <- x
-    x <- tstate$taxa_remaining()
-    items <- c(x, tstate$taxa_completed())
+  if (!is.null(x)) {
+    lifecycle::deprecate_warn(when = "v0.9.97", what = "get_iucn(x)", with = "get_iucn(sci)")
+    sci <- x
   }
+  
+  raw_data <- get_iucn_data(names_or_ids = sci, messages = messages, key = key, ...)
+  
+  out <- lapply(names(raw_data), function(input_name) {
+    result <- raw_data[[input_name]]
+    if (length(result) == 1 && is.na(result)) {
+      id <- NA_character_
+      direct <- NA
+      att <- "not found"
+    } else {
+      id <- result$taxon$sis_id
+      direct <- tolower(result$taxon$scientific_name) == tolower(input_name)
+      att <- "found"
+    }
+    list(id = id, name = input_name, att = att, direct = direct)
+  })
 
+  ids <- structure(as.character(unlist(pluck(out, "id"))), class = "iucn",
+                   match = pluck_un(out, "att", ""),
+                   name = pluck_un(out, "name", ""))
+  add_uri(ids, get_url_templates$iucn)
+}
+
+
+#' Get a IUCN Redlist taxon data
+#' 
+#' Used to get IUCN data for other functions to use.
+#' 
+#' @param latest If `TRUE`, latest use [rredlist::rl_species_latest()] instead of [rredlist::rl_species()]
+#' 
+#' @keywords internal
+get_iucn_data <- function(names_or_ids, messages = TRUE, key = NULL, latest = FALSE, ...) {
+  
+  if (inherits(names_or_ids, "character") || inherits(names_or_ids, "numeric")) {
+    tstate <- taxon_state$new(class = "iucn", names = names_or_ids)
+    items <- names_or_ids
+  } else {
+    assert_state(names_or_ids, "iucn")
+    tstate <- names_or_ids
+    names_or_ids <- tstate$taxa_remaining()
+    items <- c(names_or_ids, tstate$taxa_completed())
+  }
+  
   prog <- progressor$new(items = items, suppress = !messages)
   done <- tstate$get()
   for (i in seq_along(done)) prog$completed(names(done)[i], done[[i]]$att)
   prog$prog_start()
-
-  for (i in seq_along(x)) {
+  
+  
+  for (i in seq_along(names_or_ids)) {
     direct <- FALSE
-    mssg(messages, "\nRetrieving data for taxon '", x[i], "'\n")
-    df <- rredlist::rl_search(x[i], key = key, ...)
-
-    if (!inherits(df$result, "data.frame") || NROW(df$result) == 0) {
-      id <- NA_character_
+    mssg(messages, "\nRetrieving data for taxon '", names_or_ids[i], "'\n")
+    result <- tryCatch(
+      {
+        if (is.numeric(names_or_ids[i]) || grepl(names_or_ids[i], pattern = '^[0-9]+$')) {
+          if (latest) {
+            tmp <- rredlist::rl_sis_latest(names_or_ids[i], key = key, ...)
+          } else {
+            tmp <- rredlist::rl_sis(as.numeric(names_or_ids[i]), key = key, ...)
+          }
+        } else {
+          parts <- strsplit(names_or_ids[i], split = ' +')[[1]]
+          if (latest) {
+            rl_func_to_use <- rredlist::rl_species_latest
+          } else {
+            rl_func_to_use <- rredlist::rl_species
+          }
+          if (length(parts) == 2) {
+            tmp <- rl_func_to_use(genus = parts[1], species = parts[2], key = key, ...)
+          } else {
+            tmp <- rl_func_to_use(genus = parts[1], species = parts[2], infra = parts[3], key = key, ...)
+          }
+        }
+        tmp
+      },
+      error = function(e) {
+        NA_integer_
+      }
+    ) 
+    
+    if (length(result) == 1 && is.na(result)) {
       att <- "not found"
     } else {
-      df <- df$result[, c("taxonid", "scientific_name", "kingdom",
-                   "phylum", "order", "family", "genus", "authority")]
-
-      # should return NA if species not found
-      if (NROW(df) == 0) {
-        mssg(messages, tx_msg_not_found)
-        id <- NA_character_
-        att <- "not found"
-      }
-
-      # check for direct match
-      direct <- match(tolower(df$scientific_name), tolower(x[i]))
-
-      if (!all(is.na(direct))) {
-        id <- df$taxonid[!is.na(direct)]
-        direct <- TRUE
-        att <- "found"
-      } else {
-        direct <- FALSE
-        id <- df$taxonid
-        att <- "found"
-      }
-      # multiple matches not possible because no real search
+      att <- "found"
     }
-    res <- list(id = id, name = x[i], att = att, direct = direct)
-    prog$completed(x[i], att)
+    prog$completed(names_or_ids[i], att)
     prog$prog(att)
-    tstate$add(x[i], res)
+    tstate$add(as.character(names_or_ids[i]), result)
   }
   out <- tstate$get()
-  ids <- structure(as.character(unlist(pluck(out, "id"))), class = "iucn",
-                   match = pluck_un(out, "att", ""),
-                   name = pluck_un(out, "name", ""))
   on.exit(prog$prog_summary(), add = TRUE)
   on.exit(tstate$exit, add = TRUE)
-  add_uri(ids, get_url_templates$iucn)
+  return(out)
 }
 
+
+
 #' @export
 #' @rdname get_iucn
 as.iucn <- function(x, check = TRUE, key = NULL) {
@@ -130,34 +167,25 @@ as.iucn.iucn <- function(x, check = TRUE, key = NULL) x
 #' @export
 #' @rdname get_iucn
 as.iucn.character <- function(x, check = TRUE, key = NULL) {
-  if (length(x) == 1) {
-    make_iucn(x, check, key = key)
-  } else {
-    collapse(x, make_iucn, "iucn", check = check, key = key)
-  }
+  make_iucn(x, check = check, key = key)
 }
 
 #' @export
 #' @rdname get_iucn
 as.iucn.list <- function(x, check = TRUE, key = NULL) {
-  if (length(x) == 1) {
-    make_iucn(x, check)
-  } else {
-    collapse(x, make_iucn, "iucn", check = check)
-  }
+  as.list(make_iucn(unlist(x), check = check, key = key))
 }
 
 #' @export
 #' @rdname get_iucn
 as.iucn.numeric <- function(x, check=TRUE, key = NULL) {
-  as.iucn(as.character(x), check, key = key)
+  make_iucn(x, check = check, key = key)
 }
 
 #' @export
 #' @rdname get_iucn
 as.iucn.data.frame <- function(x, check=TRUE, key = NULL) {
-  structure(x$ids, class = "iucn", match = x$match,
-            name = x$name, uri = x$uri)
+  make_iucn(x$ids, check = check, key = key)
 }
 
 #' @export
@@ -171,18 +199,11 @@ as.data.frame.iucn <- function(x, ...){
              stringsAsFactors = FALSE)
 }
 
-make_iucn <- function(x, check = TRUE, key = NULL) {
-  make_iucn_generic(x, uu = iucn_base_url, clz = "iucn", check, key)
+#' @keywords internal
+make_iucn <- function(x, uu = iucn_base_url, clz = "iucn", check = TRUE, key = NULL) {
+  if (check) {
+    res <- get_iucn(x, key = key)
+  } else {
+    toid(x, uu, clz)
+  }
 }
-
-check_iucn <- function(x) {
-  cli <- crul::HttpClient$new(sprintf(iucn_base_url, x), headers = tx_ual)
-  tt <- cli$get()
-  tt$status_code == 200
-}
-
-check_iucn_getname <- function(x, key = NULL) {
-  rredlist::rl_search(id = as.numeric(x), key = key)
-}
-
-iucn_base_url <- "https://www.iucnredlist.org/details/%s/0"
