@@ -33,7 +33,7 @@
 #' @family taxonomic-ids
 #' @seealso [classification()]
 #'
-#' @author Scott Chamberlain, \email{myrmecocystus@@gmail.com}
+#' @author Scott Chamberlain, 
 #'
 #' @examples \dontrun{
 #' get_tpsid(sci='Poa annua')
@@ -106,11 +106,14 @@ get_tpsid <- function(sci, ask = TRUE, messages = TRUE, key = NULL,
 
   assert(sci, c("character", "taxon_state"))
   assert(ask, "logical")
-  assert(messages, "logical")
   assert(family, "character")
   assert(rank, "character")
   assert_rows(rows)
-  pchk(sciname, "sci")
+  if (!is.null(sciname)) {
+    lifecycle::deprecate_warn(when = "v0.9.97", what = "get_tpsid(sciname)", with = "get_tpsid(sci)")
+    sci <- sciname
+  }
+  
 
   if (inherits(sci, "character")) {
     tstate <- taxon_state$new(class = "tpsid", names = sci)
@@ -189,7 +192,7 @@ get_tpsid <- function(sci, ask = TRUE, messages = TRUE, key = NULL,
             message("\nMore than one tpsid found for taxon '", sci[i], "'!\n
           Enter rownumber of taxon (other inputs will return 'NA'):\n")
             rownames(df) <- 1:nrow(df)
-            print(df)
+            message(paste0(utils::capture.output(df), collapse = "\n"))
             take <- scan(n = 1, quiet = TRUE, what = 'raw')
 
             if (length(take) == 0) {
@@ -283,7 +286,10 @@ check_tpsid <- function(x){
 get_tpsid_ <- function(sci, messages = TRUE, key = NULL, rows = NA,
   sciname = NULL, ...) {
 
-  pchk(sciname, "sci")
+  if (!is.null(sciname)) {
+    lifecycle::deprecate_warn(when = "v0.9.97", what = "get_tpsid_(sciname)", with = "get_tpsid_(sci)")
+    sci <- sciname
+  }
   stats::setNames(lapply(sci, get_tpsid_help, messages = messages, key=key,
     rows = rows, ...), sci)
 }
