@@ -50,7 +50,11 @@ id2name <- function(id, db = NULL, x = NULL, ...) UseMethod("id2name")
 #' @rdname id2name
 id2name.default <- function(id, db = NULL, x = NULL, ...) {
   nstop(db)
-  pchk(x, "sci")
+  if (!is.null(x)) {
+    lifecycle::deprecate_warn(when = "v0.9.97", what = "id2name(x)", with = "id2name(sci)")
+    sci <- x
+  }
+  
   if (!is.null(x)) id <- x
   if (!db %in% id2name_sources) {
     stop("'db' must be one of ", paste(id2name_sources, collapse = ", "))
