@@ -16,15 +16,12 @@
 #' iucn_getname(name = "Cyanistes caeruleus")
 #' iucn_getname(name = "Panthera uncia")
 #'
-#' # not found in global names
-#' # iucn_getname(name = "Abronia pinsapo")
-#'
 #' # not found in IUCN search
 #' iucn_getname(name = "Acacia allenii")
 #' }
 iucn_getname <- function(name, verbose = TRUE, ...) {
   mssg(verbose, "searching Global Names ...")
-  all_names <- gni_search(sci = name, parse_names = TRUE)
+  all_names <- gna_search(sci = name, parse_names = TRUE)
   if (NROW(all_names) == 0) {
     stop("No names found matching ", name, call. = FALSE)
   }
