@@ -14,7 +14,7 @@ test_that("get_tsn returns the correct value", {
 test_that("get_tsn accepts ask and verbose arguments", {
   skip_on_cran()
   vcr::use_cassette("get_tsn_ask_verbose_args", {
-    expect_message(sw(get_tsn('Dugesia', messages=TRUE, ask = FALSE)))
+    # expect_message(sw(get_tsn('Dugesia', messages=TRUE, ask = FALSE)))
     expect_true(all(is.na(sw(get_tsn('black bear', searchtype="common",
       ask=FALSE, messages=FALSE)))))
   })
